/**
* vue-transitions
* https://www.npmjs.com/package/vue-transitions
* (c) 2017 Jason Buss
* @license MIT
* 
**/"use strict";

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

function buildExpandTransition() {
  "use strict";

  var defaultDuration = 250;

  function duration(duration, direction) {
    if (duration) {
      if ((typeof duration === "undefined" ? "undefined" : _typeof(duration)) === 'object') {
        return duration[direction];
      } else {
        return duration;
      }
    } else {
      return defaultDuration;
    }
  }

  var expandTransitionComponent = {
    functional: true,
    props: ["duration"],
    render: function render(createElement, context) {
      var data = {
        props: {
          name: "expand",
          css: false
        },
        on: {
          beforeEnter: function beforeEnter(el) {
            el.style.height = 0;
            el.style.opacity = 0;
          },
          enter: function enter(el, done) {
            var elements = [].concat(_toConsumableArray(el.children));
            var height = elements.map(function (child) {
              return child.offsetHeight;
            }).reduce(function (sum, value) {
              return sum + value;
            }, 0);
            $(el).animate({ height: height, opacity: 1 }, duration(context.props.duration, 'enter'), function () {
              el.removeAttribute("style");
              done;
            });
          },
          leave: function leave(el, done) {
            $(el).animate({ height: 0, opacity: 0 }, duration(context.props.duration, 'leave'), function () {
              el.remove();
              done;
            });
          }
        }

      };
      return createElement('transition', data, context.children);
    }
  };
  return expandTransitionComponent;
}
"use strict";

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

function buildFadeTransition() {
  "use strict";

  var defaultDuration = 250;

  function duration(duration, direction) {
    if (duration) {
      if ((typeof duration === "undefined" ? "undefined" : _typeof(duration)) === 'object') {
        return duration[direction];
      } else {
        return duration;
      }
    } else {
      return defaultDuration;
    }
  }

  var fadeTransitionComponent = {
    functional: true,
    props: ["duration"],
    render: function render(createElement, context) {
      var data = {
        props: {
          name: "fade",
          css: false
        },
        on: {
          beforeEnter: function beforeEnter(el) {
            el.style.opacity = 0;
          },
          enter: function enter(el, done) {
            $(el).animate({ opacity: 1 }, duration(context.props.duration, 'enter'), function () {
              el.removeAttribute("style");
              done;
            });
          },
          leave: function leave(el, done) {
            $(el).animate({ opacity: 0 }, duration(context.props.duration, 'leave'), function () {
              el.remove();
              done;
            });
          }
        }

      };
      return createElement('transition', data, context.children);
    }
  };
  return fadeTransitionComponent;
}
"use strict";

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

(function () {
  "use strict";

  if ((typeof exports === "undefined" ? "undefined" : _typeof(exports)) == "object") {
    module.exports = {
      Expand: buildExpandTransition(),
      Fade: buildFadeTransition(),
      Slide: buildSlideTransition()
    };
  } else if (window && window.Vue) {
    var expandTransition = buildExpandTransition();
    Vue.component('expand-transition', expandTransition);

    var fadeTransition = buildFadeTransition();
    Vue.component('fade-transition', fadeTransition);

    var slideTransition = buildSlideTransition();
    Vue.component('slide-transition', slideTransition);
  }
})();
"use strict";

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

function buildSlideTransition() {
  "use strict";

  var validDirections = ["up", "down", "left", "right"];

  var defaultDuration = 250;

  var defaultSlideLength = 10;
  var defaultDirection = "down";

  function normalizeRange(minA, maxA, minB, maxB, val) {
    // A is arbitrary new range
    // B is observed range
    // val is # to scale
    return (maxA - minA) / (maxB - minB) * (val - maxB) + maxA;
  }

  function translateSign(direction) {
    var map = {
      left: "",
      right: "-",
      up: "",
      down: "-"
    };
    return map[direction];
  }
  function translateDir(direction) {
    var map = {
      left: "X",
      right: "X",
      up: "Y",
      down: "Y"
    };
    return map[direction];
  }

  function duration(duration, state) {
    if (duration) {
      if ((typeof duration === "undefined" ? "undefined" : _typeof(duration)) === 'object') {
        return duration[state];
      } else {
        return duration;
      }
    } else {
      return defaultDuration;
    }
  }

  function direction(direction) {
    if (direction && validDirections.includes(direction)) {
      return direction;
    } else {
      return defaultDirection;
    }
  }

  function slideLength(slideLength) {
    return slideLength !== undefined ? slideLength : defaultSlideLength;
  }

  function beforeSlideEl(el, options) {
    $(el).css({
      'opacity': 0,
      '-webkit-transform': 'translate' + translateDir(options.direction) + '(' + translateSign(options.direction) + options.slideLength + 'px)',
      '-moz-transform': 'translate' + translateDir(options.direction) + '(' + translateSign(options.direction) + options.slideLength + 'px)',
      'transform': 'translate' + translateDir(options.direction) + '(' + translateSign(options.direction) + options.slideLength + 'px)'
    });
  }

  function slideEl(el, options, done) {
    var o = options.state === "enter" ? 1 : 0;
    var s = options.state === "enter" ? 0 : 1;

    var cb = done || function () {};
    $(el).animate({ opacity: o }, {
      duration: options.duration,
      step: function step(now, fn) {
        fn.start = s;
        fn.end = o;
        var n = normalizeRange(0, options.slideLength, fn.start, fn.end, now);
        var t = options.state === "enter" ? options.slideLength - n : n;
        $(el).css({
          'opacity': now,
          '-webkit-transform': 'translate' + translateDir(options.direction) + '(' + translateSign(options.direction) + t + 'px)',
          '-moz-transform': 'translate' + translateDir(options.direction) + '(' + translateSign(options.direction) + t + 'px)',
          'transform': 'translate' + translateDir(options.direction) + '(' + translateSign(options.direction) + t + 'px)'
        });
      }, done: function done() {
        cb();
      }
    });
  }

  var slideTransitionComponent = {
    functional: true,
    props: ["duration", "direction", "slideLength"],
    render: function render(createElement, context) {
      var data = {
        props: {
          name: "slide",
          css: false
        },
        on: {
          beforeEnter: function beforeEnter(el) {
            beforeSlideEl(el, { direction: direction(context.props.direction), slideLength: slideLength(context.props.slideLength) });
          },
          enter: function enter(el, done) {
            slideEl(el, {
              direction: direction(context.props.direction),
              slideLength: slideLength(context.props.slideLength),
              duration: duration(context.props.duration, 'enter'),
              state: "enter"
            }, function () {
              el.removeAttribute("style");
              done;
            });
          },
          leave: function leave(el, done) {
            slideEl(el, {
              direction: direction(context.props.direction),
              slideLength: slideLength(context.props.slideLength),
              duration: duration(context.props.duration, 'leave'),
              state: "leave"
            }, function () {
              el.remove();
              done;
            });
          }
        }

      };
      return createElement('transition', data, context.children);
    }
  };
  return slideTransitionComponent;
}
