function buildSlideTransition() {
  "use strict";

  const validDirections = ["up", "down", "left", "right"]

  const defaultDuration = 250

  const defaultSlideLength = 10
  const defaultDirection = "down"


  function normalizeRange(minA, maxA, minB, maxB, val) {
    // A is arbitrary new range
    // B is observed range
    // val is # to scale
    return (maxA - minA) / (maxB - minB) * (val - maxB) + maxA
  }

  function translateSign(direction) {
    var map = {
      left: "",
      right: "-",
      up: "",
      down: "-",
    }
    return map[direction]
  }
  function translateDir(direction) {
    var map = {
      left: "X",
      right: "X",
      up: "Y",
      down: "Y",
    }
    return map[direction]
  }

  function duration(duration, state) {
    if (duration) {
      if (typeof duration === 'object') {
        return duration[state]
      } else {
        return duration
      }
    } else {
      return defaultDuration
    }
  }

  function direction(direction) {
    if (direction && validDirections.includes(direction)) {
      return direction
    } else {
      return defaultDirection
    }
  }

  function slideLength(slideLength) {
    return slideLength !== undefined ? slideLength : defaultSlideLength
  }

  function beforeSlideEl(el, options) {
    $(el).css({
      'opacity': 0,
      '-webkit-transform':'translate'+translateDir(options.direction)+'('+translateSign(options.direction)+options.slideLength+'px)',
      '-moz-transform':'translate'+translateDir(options.direction)+'('+translateSign(options.direction)+options.slideLength+'px)',
      'transform':'translate'+translateDir(options.direction)+'('+translateSign(options.direction)+options.slideLength+'px)',
    })
  }

  function slideEl(el, options, done) {
    var o = options.state === "enter" ? 1 : 0
    var s = options.state === "enter" ? 0 : 1

    var cb = done || function() {}
    $(el).animate({opacity: o},{
      duration: options.duration,
      step:function(now, fn){
        fn.start = s
        fn.end = o
        var n = normalizeRange(0, options.slideLength, fn.start, fn.end, now)
        var t = options.state === "enter" ? options.slideLength - n : n
        $(el).css({
          'opacity': now,
          '-webkit-transform':'translate'+translateDir(options.direction)+'('+translateSign(options.direction)+t+'px)',
          '-moz-transform':'translate'+translateDir(options.direction)+'('+translateSign(options.direction)+t+'px)',
          'transform':'translate'+translateDir(options.direction)+'('+translateSign(options.direction)+t+'px)',
        })
      }, done: () => { cb() }
    })
  }


  const slideTransitionComponent = {
    functional: true,
    props: ["duration", "direction", "slideLength"],
    render: (createElement, context) => {
      let data = {
        props: {
          name: "slide",
          css: false
        },
        on: {
          beforeEnter(el) {
            beforeSlideEl(el, {direction: direction(context.props.direction), slideLength: slideLength(context.props.slideLength)})
          },

          enter(el, done) {
            slideEl(el, {
              direction: direction(context.props.direction),
              slideLength: slideLength(context.props.slideLength),
              duration: duration(context.props.duration, 'enter'),
              state: "enter"
            }, () => {
              el.removeAttribute("style")
              done
            })
          },

          leave(el, done) {
            slideEl(el, {
              direction: direction(context.props.direction),
              slideLength: slideLength(context.props.slideLength),
              duration: duration(context.props.duration, 'leave'),
              state: "leave"
            }, () => {
              el.remove()
              done
            })
          }
        },

      }
      return createElement('transition', data, context.children)
    }
  }
  return slideTransitionComponent
}